"""
 ######   #######  ##     ## ########  ##    ##
##    ## ##     ## ##     ## ##     ##  ##  ##
##       ##     ## ##     ## ##     ##   ####
##       ##     ## ######### ########     ##
##       ##     ## ##     ## ##           ##
##    ## ##     ## ##     ## ##           ##
 ######   #######  ##     ## ##           ##

An API Wrapper for Company Of Heroes API

Made by Andrés Garrido
Github: https://github.com/AndresGL01

PD: Nerf Guastatori
"""

from .client import (
    get_api_client
)

from .leaderboards import Codes, SortType
from .exceptions import *
